summaryrefslogtreecommitdiffstats
path: root/include/pacemaker.h
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-17 07:45:40 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-04-17 07:45:40 +0000
commit07d7f4cfa4b10de87a31b68191036ff446add675 (patch)
tree7162524d8aaf1aef62d2f4fa51f595ed113981ff /include/pacemaker.h
parentAdding upstream version 2.1.6. (diff)
downloadpacemaker-0d560556df519c6626cda7660f843a815b3c227e.tar.xz
pacemaker-0d560556df519c6626cda7660f843a815b3c227e.zip
Adding upstream version 2.1.7.upstream/2.1.7
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'include/pacemaker.h')
-rw-r--r--include/pacemaker.h53
1 files changed, 46 insertions, 7 deletions
diff --git a/include/pacemaker.h b/include/pacemaker.h
index f5c375a..ffa99ff 100644
--- a/include/pacemaker.h
+++ b/include/pacemaker.h
@@ -12,8 +12,8 @@
# include <glib.h>
# include <libxml/tree.h>
+# include <crm/common/scheduler.h>
# include <crm/cib/cib_types.h>
-# include <crm/pengine/pe_types.h>
# include <crm/stonith-ng.h>
@@ -202,13 +202,13 @@ int pcmk_pacemakerd_status(xmlNodePtr *xml, const char *ipc_name,
* \param[in,out] rsc Resource to calculate digests for
* \param[in] node Node whose operation history should be used
* \param[in] overrides Hash table of configuration parameters to override
* \param[in] data_set Cluster working set (with status)
*
* \return Standard Pacemaker return code
*/
-int pcmk_resource_digests(xmlNodePtr *xml, pe_resource_t *rsc,
- const pe_node_t *node, GHashTable *overrides,
- pe_working_set_t *data_set);
+int pcmk_resource_digests(xmlNodePtr *xml, pcmk_resource_t *rsc,
+ const pcmk_node_t *node, GHashTable *overrides,
+ pcmk_scheduler_t *scheduler);
/*!
* \brief Simulate a cluster's response to events
@@ -219,7 +219,7 @@ int pcmk_resource_digests(xmlNodePtr *xml, pe_resource_t *rsc,
* simulation. Output can be modified with various flags.
*
* \param[in,out] xml The destination for the result, as an XML tree
- * \param[in,out] data_set Working set for the cluster
+ * \param[in,out] scheduler Scheduler data
* \param[in] injections A structure containing cluster events
* (node up/down, tickets, injected operations)
* \param[in] flags A bitfield of :pcmk_sim_flags to modify
@@ -238,7 +238,7 @@ int pcmk_resource_digests(xmlNodePtr *xml, pe_resource_t *rsc,
*
* \return Standard Pacemaker return code
*/
-int pcmk_simulate(xmlNodePtr *xml, pe_working_set_t *data_set,
+int pcmk_simulate(xmlNodePtr *xml, pcmk_scheduler_t *scheduler,
const pcmk_injections_t *injections, unsigned int flags,
unsigned int section_opts, const char *use_date,
const char *input_file, const char *graph_file,
@@ -337,6 +337,45 @@ int pcmk_show_result_code(xmlNodePtr *xml, int code, enum pcmk_result_type type,
int pcmk_list_result_codes(xmlNodePtr *xml, enum pcmk_result_type type,
uint32_t flags);
+/*!
+ * \brief List available providers for the given OCF agent
+ *
+ * \param[in,out] xml The destination for the result, as an XML tree
+ * \param[in] agent_spec Resource agent name
+ *
+ * \return Standard Pacemaker return code
+ */
+int pcmk_list_alternatives(xmlNodePtr *xml, const char *agent_spec);
+
+/*!
+ * \brief List all agents available for the named standard and/or provider
+ *
+ * \param[in,out] xml The destination for the result, as an XML tree
+ * \param[in] agent_spec STD[:PROV]
+ *
+ * \return Standard Pacemaker return code
+ */
+int pcmk_list_agents(xmlNodePtr *xml, char *agent_spec);
+
+/*!
+ * \brief List all available OCF providers for the given agent
+ *
+ * \param[in,out] xml The destination for the result, as an XML tree
+ * \param[in] agent_spec Resource agent name
+ *
+ * \return Standard Pacemaker return code
+ */
+int pcmk_list_providers(xmlNodePtr *xml, const char *agent_spec);
+
+/*!
+ * \brief List all available resource agent standards
+ *
+ * \param[in,out] xml The destination for the result, as an XML tree
+ *
+ * \return Standard Pacemaker return code
+ */
+int pcmk_list_standards(xmlNodePtr *xml);
+
#ifdef BUILD_PUBLIC_LIBPACEMAKER
/*!
@@ -202,13 +202,13 @@ int pcmk_pacemakerd_status(xmlNodePtr *xml, const char *ipc_name,
* \param[in] node Node whose operation history should be used
* \param[in] overrides Hash table of configuration parameters to override
- * \param[in] data_set Cluster working set (with status)
+ * \param[in] scheduler Scheduler data (with status)
*
* \return Standard Pacemaker return code